==> eam-wshub-proxyclient-11.4-10-sources.jar: net/datastream/schemas/mp_fields/HORIZONTALVERTICALDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Classe Java pour HORIZONTALVERTICALDETAILS_Type complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="HORIZONTALVERTICALDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATIONSHIPTYPEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HORIZONTALOFFSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HORIZONTALOFFSETUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HORIZONTALOFFSETTYPEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VERTICALOFFSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VERTICALOFFSETUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VERTICALOFFSETTYPEID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HORIZONTALVERTICALDETAILS_Type", propOrder = {
    "relationshiptypeid",
    "horizontaloffset",
    "horizontaloffsetuom",
    "horizontaloffsettypeid",
    "verticaloffset",
    "verticaloffsetuom",
    "verticaloffsettypeid"
})
public class HORIZONTALVERTICALDETAILS_Type {

    @XmlElement(name = "RELATIONSHIPTYPEID")
    protected TYPE_Type relationshiptypeid;
    @XmlElement(name = "HORIZONTALOFFSET")
    protected QUANTITY horizontaloffset;
    @XmlElement(name = "HORIZONTALOFFSETUOM")
    protected LINEARUOMID_Type horizontaloffsetuom;
    @XmlElement(name = "HORIZONTALOFFSETTYPEID")
    protected TYPE_Type horizontaloffsettypeid;
    @XmlElement(name = "VERTICALOFFSET")
    protected QUANTITY verticaloffset;
    @XmlElement(name = "VERTICALOFFSETUOM")
    protected LINEARUOMID_Type verticaloffsetuom;
    @XmlElement(name = "VERTICALOFFSETTYPEID")
    protected TYPE_Type verticaloffsettypeid;

    /**
     * Obtient la valeur de la propriété relationshiptypeid.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getRELATIONSHIPTYPEID() {
        return relationshiptypeid;
    }

    /**
     * Définit la valeur de la propriété relationshiptypeid.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setRELATIONSHIPTYPEID(TYPE_Type value) {
        this.relationshiptypeid = value;
    }

    /**
     * Obtient la valeur de la propriété horizontaloffset.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getHORIZONTALOFFSET() {
        return horizontaloffset;
    }

    /**
     * Définit la valeur de la propriété horizontaloffset.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setHORIZONTALOFFSET(QUANTITY value) {
        this.horizontaloffset = value;
    }

    /**
     * Obtient la valeur de la propriété horizontaloffsetuom.
     * 
     * @return
     *     possible object is
     *     {@link LINEARUOMID_Type }
     *     
     */
    public LINEARUOMID_Type getHORIZONTALOFFSETUOM() {
        return horizontaloffsetuom;
    }

    /**
     * Définit la valeur de la propriété horizontaloffsetuom.
     * 
     * @param value
     *     allowed object is
     *     {@link LINEARUOMID_Type }
     *     
     */
    public void setHORIZONTALOFFSETUOM(LINEARUOMID_Type value) {
        this.horizontaloffsetuom = value;
    }

    /**
     * Obtient la valeur de la propriété horizontaloffsettypeid.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getHORIZONTALOFFSETTYPEID() {
        return horizontaloffsettypeid;
    }

    /**
     * Définit la valeur de la propriété horizontaloffsettypeid.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setHORIZONTALOFFSETTYPEID(TYPE_Type value) {
        this.horizontaloffsettypeid = value;
    }

    /**
     * Obtient la valeur de la propriété verticaloffset.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getVERTICALOFFSET() {
        return verticaloffset;
    }

    /**
     * Définit la valeur de la propriété verticaloffset.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setVERTICALOFFSET(QUANTITY value) {
        this.verticaloffset = value;
    }

    /**
     * Obtient la valeur de la propriété verticaloffsetuom.
     * 
     * @return
     *     possible object is
     *     {@link LINEARUOMID_Type }
     *     
     */
    public LINEARUOMID_Type getVERTICALOFFSETUOM() {
        return verticaloffsetuom;
    }

    /**
     * Définit la valeur de la propriété verticaloffsetuom.
     * 
     * @param value
     *     allowed object is
     *     {@link LINEARUOMID_Type }
     *     
     */
    public void setVERTICALOFFSETUOM(LINEARUOMID_Type value) {
        this.verticaloffsetuom = value;
    }

    /**
     * Obtient la valeur de la propriété verticaloffsettypeid.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getVERTICALOFFSETTYPEID() {
        return verticaloffsettypeid;
    }

    /**
     * Définit la valeur de la propriété verticaloffsettypeid.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setVERTICALOFFSETTYPEID(TYPE_Type value) {
        this.verticaloffsettypeid = value;
    }

}

==> eam-wshub-proxyclient-12.1-0-sources.jar: net/datastream/schemas/mp_fields/HORIZONTALVERTICALDETAILS_Type.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;
import org.openapplications.oagis_segments.QUANTITY;


/**
 * <p>Java class for HORIZONTALVERTICALDETAILS_Type complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="HORIZONTALVERTICALDETAILS_Type">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RELATIONSHIPTYPEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HORIZONTALOFFSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HORIZONTALOFFSETUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}HORIZONTALOFFSETTYPEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VERTICALOFFSET" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VERTICALOFFSETUOM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}VERTICALOFFSETTYPEID" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "HORIZONTALVERTICALDETAILS_Type", propOrder = {
    "relationshiptypeid",
    "horizontaloffset",
    "horizontaloffsetuom",
    "horizontaloffsettypeid",
    "verticaloffset",
    "verticaloffsetuom",
    "verticaloffsettypeid"
})
public class HORIZONTALVERTICALDETAILS_Type {

    @XmlElement(name = "RELATIONSHIPTYPEID")
    protected TYPE_Type relationshiptypeid;
    @XmlElement(name = "HORIZONTALOFFSET")
    protected QUANTITY horizontaloffset;
    @XmlElement(name = "HORIZONTALOFFSETUOM")
    protected LINEARUOMID_Type horizontaloffsetuom;
    @XmlElement(name = "HORIZONTALOFFSETTYPEID")
    protected TYPE_Type horizontaloffsettypeid;
    @XmlElement(name = "VERTICALOFFSET")
    protected QUANTITY verticaloffset;
    @XmlElement(name = "VERTICALOFFSETUOM")
    protected LINEARUOMID_Type verticaloffsetuom;
    @XmlElement(name = "VERTICALOFFSETTYPEID")
    protected TYPE_Type verticaloffsettypeid;

    /**
     * Gets the value of the relationshiptypeid property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getRELATIONSHIPTYPEID() {
        return relationshiptypeid;
    }

    /**
     * Sets the value of the relationshiptypeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setRELATIONSHIPTYPEID(TYPE_Type value) {
        this.relationshiptypeid = value;
    }

    /**
     * Gets the value of the horizontaloffset property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getHORIZONTALOFFSET() {
        return horizontaloffset;
    }

    /**
     * Sets the value of the horizontaloffset property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setHORIZONTALOFFSET(QUANTITY value) {
        this.horizontaloffset = value;
    }

    /**
     * Gets the value of the horizontaloffsetuom property.
     * 
     * @return
     *     possible object is
     *     {@link LINEARUOMID_Type }
     *     
     */
    public LINEARUOMID_Type getHORIZONTALOFFSETUOM() {
        return horizontaloffsetuom;
    }

    /**
     * Sets the value of the horizontaloffsetuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link LINEARUOMID_Type }
     *     
     */
    public void setHORIZONTALOFFSETUOM(LINEARUOMID_Type value) {
        this.horizontaloffsetuom = value;
    }

    /**
     * Gets the value of the horizontaloffsettypeid property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getHORIZONTALOFFSETTYPEID() {
        return horizontaloffsettypeid;
    }

    /**
     * Sets the value of the horizontaloffsettypeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setHORIZONTALOFFSETTYPEID(TYPE_Type value) {
        this.horizontaloffsettypeid = value;
    }

    /**
     * Gets the value of the verticaloffset property.
     * 
     * @return
     *     possible object is
     *     {@link QUANTITY }
     *     
     */
    public QUANTITY getVERTICALOFFSET() {
        return verticaloffset;
    }

    /**
     * Sets the value of the verticaloffset property.
     * 
     * @param value
     *     allowed object is
     *     {@link QUANTITY }
     *     
     */
    public void setVERTICALOFFSET(QUANTITY value) {
        this.verticaloffset = value;
    }

    /**
     * Gets the value of the verticaloffsetuom property.
     * 
     * @return
     *     possible object is
     *     {@link LINEARUOMID_Type }
     *     
     */
    public LINEARUOMID_Type getVERTICALOFFSETUOM() {
        return verticaloffsetuom;
    }

    /**
     * Sets the value of the verticaloffsetuom property.
     * 
     * @param value
     *     allowed object is
     *     {@link LINEARUOMID_Type }
     *     
     */
    public void setVERTICALOFFSETUOM(LINEARUOMID_Type value) {
        this.verticaloffsetuom = value;
    }

    /**
     * Gets the value of the verticaloffsettypeid property.
     * 
     * @return
     *     possible object is
     *     {@link TYPE_Type }
     *     
     */
    public TYPE_Type getVERTICALOFFSETTYPEID() {
        return verticaloffsettypeid;
    }

    /**
     * Sets the value of the verticaloffsettypeid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TYPE_Type }
     *     
     */
    public void setVERTICALOFFSETTYPEID(TYPE_Type value) {
        this.verticaloffsettypeid = value;
    }

}
